@@ -3,7 +3,7 @@ from functools import reduce
 
 __author__ = """Romain Picard"""
 __email__ = 'romain.picard@oakbits.com'
-__version__ = '1.5.0'
+__version__ = '1.5.1'
 
 
 # bins is a tuple of (cut point, count)
@@ -71,7 +71,9 @@ def _trim(h):
             bins[i][1] + bins[i+1][1]
         )
         del bins[i+1]
-        _update_diffs(h, i)
+        if h.diffs is not None:
+            del h.diffs[i]
+            _update_diffs(h, i)
 
     h.bins = bins
     return h
@@ -175,8 +177,14 @@ def update(h, value, count=1):
 
     if index == -1:
         bins.append((value, count))
+        if h.diffs is not None:
+            h.diffs.append(h.bins[-1][0] - h.bins[-2][0])
     else:
         bins.insert(index, (value, count))
+        if h.diffs is not None:
+            h.diffs.insert(index, None)
+            _update_diffs(h, index)
+
     h.bins = bins
     if h.min is None or h.min > value:
         h.min = value
@@ -197,7 +205,7 @@ def merge(h1, h2):
         bins in this Distogram is equal to the number of bins in h1.
     '''
     h = h1
-    for i in h2:
+    for i in h2.bins:
         h = update(h, i[0], i[1])
     return h
 
